import click
import questionary

from simple_semver_toml.service import bump, version


@click.group()
@click.version_option()
def cli():
    pass


@cli.command("version")
@click.option("--path", default=".", help="The path to the pyproject.toml file")
def cli_version(path):
    version(path)


@cli.command("bump")
@click.option("--path", default=".", help="The path to the pyproject.toml file")
@click.option("--quiet", "-q", is_flag=True, help="Quiet mode")
@click.option("--yes", "-y", is_flag=True, help="No interaction")
@click.option("--dry-run", "-d", is_flag=True, help="Dry run")
@click.argument(
    "bump_type",
    type=click.Choice(["major", "minor", "patch", "prerelease", "build"]),
    required=False,
)
def cli_bump(path, bump_type, yes, quiet, dry_run):
    if bump_type is None:
        bump_type = questionary.select(
            "Select the type of bump",
            choices=["major", "minor", "patch", "prerelease", "build"],
        ).unsafe_ask()

    bump(path, bump_type, yes, quiet, dry_run)


if __name__ == "__main__":
    cli()
